==> zio-aws-ssm_3-5.17.116.1-sources.jar: zio/aws/ssm/model/DescribeAvailablePatchesResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeAvailablePatchesResponse(
    patches: Option[Iterable[zio.aws.ssm.model.Patch]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse = {
    import DescribeAvailablePatchesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
      .builder()
      .optionallyWith(
        patches.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.patches)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly =
    zio.aws.ssm.model.DescribeAvailablePatchesResponse.wrap(buildAwsValue())
}
object DescribeAvailablePatchesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.DescribeAvailablePatchesResponse =
      zio.aws.ssm.model.DescribeAvailablePatchesResponse(
        patches.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def patches: Option[List[zio.aws.ssm.model.Patch.ReadOnly]]
    def nextToken: Option[NextToken]
    def getPatches: ZIO[Any, AwsError, List[zio.aws.ssm.model.Patch.ReadOnly]] =
      AwsError.unwrapOptionField("patches", patches)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ) extends zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly {
    override val patches: Option[List[zio.aws.ssm.model.Patch.ReadOnly]] = scala
      .Option(impl.patches())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ssm.model.Patch.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ): zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ssm_3-7.28.29.11-sources.jar: zio/aws/ssm/model/DescribeAvailablePatchesResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeAvailablePatchesResponse(
    patches: Optional[Iterable[zio.aws.ssm.model.Patch]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse = {
    import DescribeAvailablePatchesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
      .builder()
      .optionallyWith(
        patches.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.patches)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly =
    zio.aws.ssm.model.DescribeAvailablePatchesResponse.wrap(buildAwsValue())
}
object DescribeAvailablePatchesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.DescribeAvailablePatchesResponse =
      zio.aws.ssm.model.DescribeAvailablePatchesResponse(
        patches.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def patches: Optional[List[zio.aws.ssm.model.Patch.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getPatches: ZIO[Any, AwsError, List[zio.aws.ssm.model.Patch.ReadOnly]] =
      AwsError.unwrapOptionField("patches", patches)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ) extends zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly {
    override val patches: Optional[List[zio.aws.ssm.model.Patch.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.patches())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.Patch.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeAvailablePatchesResponse
  ): zio.aws.ssm.model.DescribeAvailablePatchesResponse.ReadOnly = new Wrapper(
    impl
  )
}
